function [ x, u, v, iter, avg_inact] = kr_box(M,c,a,b,A2,A1,tol,sil)

% straightforward extension from the one-sided case
% notation has to be adapted to be consistent


% solves: min c'x + (1/2) x'Mx  subject to: a <= x <=b
% Assumption: Q symmetric positive definite,
% KKT: Mx + c - u + v = 0; u o (a-x) = 0; v o (x-b) = 0; u,v >=0


n = length( c);
k = 0;                          % iteration count
avg_inact = 0;
done = 0;
A3=[]; A4=[];
I = ones(n,1);
I(A1) = 0;
I(A2) = 0;
I = find(I>0);

while done < 1;
	k = k + 1;              % start a new iteration
 
% solve system on inactive set
         x = zeros( n,1);
         u = x; v = x; 		% initialize
	x( A1) = a( A1);
	x( A2) = b( A2);
	x( A3) = a( A3);
	x( A4) = b( A4); 
    avg_inact = avg_inact + length(I);
	if ~isempty(I); rhs = -c( I);
		if ~isempty(A1);  rhs = rhs-M(I,A1)*x(A1); end;
		if ~isempty(A2);  rhs = rhs-M(I,A2)*x(A2); end;
		if ~isempty(A3);  rhs = rhs-M(I,A3)*x(A3); end;
		if ~isempty(A4);  rhs = rhs-M(I,A4)*x(A4); end;
		x( I) = M( I, I) \ rhs;
	end;
	if ~isempty(A4); v( A4) = -c( A4) - M( A4,:) * x; end;
	if ~isempty(A3); u( A3) = +c( A3) + M( A3,:) * x; end;
	if ~isempty(A2); v( A2) = -c( A2) - M( A2,:) * x; end;
	if ~isempty(A1); u( A1) = +c( A1) + M( A1,:) * x; end;
    
% check stopping condition
	ok1 = (min(b-x) >=-tol);
	ok2 = (min(x-a) >=-tol);
	ok3 = (min(u) >=-tol);
	ok4 = (min(v) >=-tol);
	done = ok1 & ok2 & ok3 & ok4;  % stopping condition
    if k>100
        done= 1;
        if(sil == 0)
            disp( ' max it.'); 
        end
    end

	A1 = find( (x-a) < 0);	% outside lower bound
	A2 = find( (x-b) > 0);	% outside upper bound
	A3 = find( u > 0);	% dual to lower bound active
	A4 = find( v > 0);	% dual to upper bound active
	J = zeros(n,1);
	A = [ A1; A2; A3; A4];	% indices of (new) active variables
	J(A) = ones(length(A),1);
	I = find(J<1);		% inactive variables

 	
    
    if(sil == 0)
        fx = .5*x'*M*x+c'*x;
        err_p1 = log10(max( max(x-b),1e-99));
        err_p2 = log10(max( max(a-x),1e-99));
        err_d1 = log10(max( -min(u), 1e-99));
        err_d2 = log10(max( -min(v), 1e-99));
        fprintf( '%8d  %6d  %10.3f  %10.3f  %8.3f  %8.3f %10.10f\n',k,length(I),err_p1,err_p2,err_d1,err_d2,fx);
    end
end;                 % end while
iter = k;
v = -v;
avg_inact = avg_inact/iter;





